summaryrefslogtreecommitdiff
path: root/src/pandoc.hs
diff options
context:
space:
mode:
authorJonas Smedegaard <dr@jones.dk>2012-06-20 22:41:55 +0200
committerJonas Smedegaard <dr@jones.dk>2012-06-20 22:41:55 +0200
commitf16ccad90c42feb754b6bc13d107759a04bb31c7 (patch)
tree00e2995ad9c91f5dd4b982098ca2962647fae0c2 /src/pandoc.hs
parenta854a180416ffa6e1f45023025924fab3161a993 (diff)
Imported Upstream version 1.9.4.1
Diffstat (limited to 'src/pandoc.hs')
-rw-r--r--src/pandoc.hs10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/pandoc.hs b/src/pandoc.hs
index a25e7d8d6..34d136aa8 100644
--- a/src/pandoc.hs
+++ b/src/pandoc.hs
@@ -37,7 +37,7 @@ import Text.Pandoc.Shared ( tabFilter, ObfuscationMethod (..), readDataFile,
import Text.Pandoc.XML ( toEntities, fromEntities )
import Text.Pandoc.SelfContained ( makeSelfContained )
import Text.Pandoc.Highlighting ( languages, Style, tango, pygments,
- espresso, kate, haddock, monochrome )
+ espresso, zenburn, kate, haddock, monochrome )
import System.Environment ( getArgs, getProgName )
import System.Exit ( exitWith, ExitCode (..) )
import System.FilePath
@@ -101,7 +101,7 @@ data Opt = Opt
, optOutputFile :: String -- ^ Name of output file
, optNumberSections :: Bool -- ^ Number sections in LaTeX
, optSectionDivs :: Bool -- ^ Put sections in div tags in HTML
- , optIncremental :: Bool -- ^ Use incremental lists in Slidy/S5
+ , optIncremental :: Bool -- ^ Use incremental lists in Slidy/Slideous/S5
, optSelfContained :: Bool -- ^ Make HTML accessible offline
, optSmart :: Bool -- ^ Use smart typography
, optOldDashes :: Bool -- ^ Parse dashes like pandoc <=1.8.2.1
@@ -349,6 +349,7 @@ options =
"pygments" -> return pygments
"tango" -> return tango
"espresso" -> return espresso
+ "zenburn" -> return zenburn
"kate" -> return kate
"monochrome" -> return monochrome
"haddock" -> return haddock
@@ -453,7 +454,7 @@ options =
, Option "i" ["incremental"]
(NoArg
(\opt -> return opt { optIncremental = True }))
- "" -- "Make list items display incrementally in Slidy/S5"
+ "" -- "Make list items display incrementally in Slidy/Slideous/S5"
, Option "" ["slide-level"]
(ReqArg
@@ -886,6 +887,7 @@ main = do
let slideVariant = case writerName' of
"s5" -> S5Slides
"slidy" -> SlidySlides
+ "slideous" -> SlideousSlides
"dzslides" -> DZSlides
_ -> NoSlides
@@ -1051,7 +1053,7 @@ main = do
where result = w writerOptions doc2 ++ ['\n' | not standalone']
htmlFormat = writerName' `elem`
["html","html+lhs","html5","html5+lhs",
- "s5","slidy","dzslides"]
+ "s5","slidy","slideous","dzslides"]
selfcontain = if selfContained && htmlFormat
then makeSelfContained datadir
else return